@@ -7,11 +7,10 @@
 #endif
 
 #define GPDATADIR "/pari/data"
-#define GPMISCDIR "/pari/"
 #define SHELL_Q '"'
 #define DL_DFLT_NAME "libpari.dll"
 
-#define PARIVERSION "GP/PARI CALCULATOR Version 2.1.7 (released)"
+#define PARIVERSION "GP/PARI CALCULATOR Version 2.3.0 (released)"
 #ifdef __cplusplus
 #  define PARIINFO_PRE "C++"
 #else
@@ -27,8 +26,9 @@
 #  define PARIINFO_POST "ix86 running Windows 3.2 (ix86 kernel) 32-bit version"
 #endif
 #define PARIINFO PARIINFO_PRE/**/PARIINFO_POST
-#define PARI_VERSION_CODE 131335
+#define PARI_VERSION_CODE 131840
 #define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
+#define PARI_VERSION_SHIFT 8
 
 #define PARI_DOUBLE_FORMAT 1
 #ifdef _MSC_VER /* MSVC inline directive */
@@ -42,6 +42,7 @@
 #endif
 
 #ifdef __EMX__
+#  define STACK_CHECK
 #  define READLINE
 #  define READLINE_LIBRARY
 #  define HAS_RL_MESSAGE
@@ -63,12 +64,13 @@
 /* Headers are clean - ulong not defined */
 #define ULONG_NOT_DEFINED
 
-#ifndef WINCE
+#if !defined(WINCE) && !(defined(_WIN32) && defined(_MSC_VER))
 /* Timings: Don't use times because of the HZ / CLK_TCK confusion. */
 #  define USE_FTIME 1
 #  define HAS_STRFTIME
-/* This might work on NT ??? */
-/* #  define HAS_OPENDIR */
+#endif
+#if defined(_WIN32) && defined(_MSC_VER)
+#  define HAS_STAT
 #endif
 
 #endif
